DELIMITER $$

DROP PROCEDURE IF EXISTS `adobeCRM`.`getSalesUnitForecastsByRegionId`$$

CREATE PROCEDURE `adobeCRM`.`getSalesUnitForecastsByRegionId` ( IN regionId INT )
	BEGIN
		SELECT 
			u.region_id, r.region_name, u.user_id, u.fname, u.lname, u.is_manager, u.is_regional_manager,
			(
				SELECT 
					CAST( SUM( cd.estimated_revenue ) AS DECIMAL( 14, 2 ) )
				FROM
					users uu
					INNER JOIN sales_reps sr
					INNER JOIN client_deals cd
				WHERE
					uu.user_id = sr.user_id AND
					cd.user_id = uu.user_id AND
					uu.region_id = regionId AND
					sr.manager_user_id = sm.user_id
				GROUP BY
					sr.manager_user_id, uu.region_id
			) AS total_estimated_revenue,
			(
				SELECT 
					CAST( SUM( sq.quota_value ) AS DECIMAL( 14, 2 ) )
				FROM
					users uu
					INNER JOIN sales_reps sr
					INNER JOIN sales_quotas sq
				WHERE
					uu.user_id = sr.user_id AND
					sq.user_id = uu.user_id AND
					uu.region_id = regionId AND
					sr.manager_user_id = sm.user_id
				GROUP BY
					sr.manager_user_id, uu.region_id
			) AS total_sales_quota
		FROM 
			sales_managers sm
			INNER JOIN users u
			INNER JOIN regions r
		WHERE
			u.user_id = sm.user_id AND
			u.region_id = regionId AND
			r.region_id = regionId;
    END$$

DELIMITER;

