DELIMITER $$

DROP PROCEDURE IF EXISTS `adobeCRM`.`getTop10ClientDealsByRegionId`$$


CREATE PROCEDURE `adobeCRM`.`getTop10ClientDealsByRegionId` ( IN regionId INT )
	BEGIN
		SELECT ca.client_id, ca.client_name, ca.industry AS client_industry, ca.annual_revenue AS client_annual_revenue,
					cd.client_deal_id, cd.title, cd.description, cd.created_date,
						cd.priority_level, cd.estimated_revenue,
							cd.estimated_close_date, cd.probability,
				lst.*,
				rt.*,
				stage.*,
				stat.*,
				u.user_id, u.fname, u.lname, u.is_manager,
				r.region_id, r.region_name
		FROM users AS u
			INNER JOIN client_deals AS cd
			INNER JOIN regions AS r
			INNER JOIN client_accounts AS ca
			INNER JOIN lead_source_types AS lst
			INNER JOIN rating_types AS rt
			INNER JOIN stage_types AS stage
			INNER JOIN status_types AS stat
		WHERE
			u.region_id = regionId AND
			r.region_id = regionId AND 
			u.user_id = cd.user_id AND
			ca.client_id = cd.client_id AND
			cd.lead_source_type_id = lst.lead_source_type_id AND
			cd.rating_type_id = rt.rating_type_id AND
			cd.stage_type_id = stage.stage_type_id AND
			cd.status_type_id = stat.status_type_id
		GROUP BY
			cd.client_deal_id
		ORDER BY
			cd.estimated_revenue, u.user_id DESC
		LIMIT 10;
	END$$

DELIMITER;

