DELIMITER $$

DROP PROCEDURE IF EXISTS `adobeCRM`.`getTop10ClientDealsByUserId` $$


CREATE PROCEDURE `adobeCRM`.`getTop10ClientDealsByUserId` ( IN userId INT,
															IN lBoundDate DATETIME,
															IN uBoundDate DATETIME )
	BEGIN
		
		SELECT ca.client_id, ca.client_name, ca.industry AS client_industry, ca.annual_revenue AS client_annual_revenue,
					cd.client_deal_id, cd.title AS client_deal_title, cd.description AS client_deal_description, cd.created_date AS client_deal_datestamp,
						cd.priority_level AS client_deal_priority_level, cd.estimated_revenue AS client_deal_estimated_revenue,
							cd.estimated_close_date AS client_deal_estimated_close_date, cd.probability AS client_deal_probability,
				lst.*,
				rt.*,
				stage.*,
				stat.*,
				u.user_id, u.fname, u.lname, u.is_manager,
				r.region_id, r.region_name
		FROM client_deals AS cd
			INNER JOIN users AS u
			INNER JOIN regions AS r
			INNER JOIN client_accounts AS ca
			INNER JOIN lead_source_types AS lst
			INNER JOIN rating_types AS rt
			INNER JOIN stage_types AS stage
			INNER JOIN status_types AS stat
		WHERE
			cd.user_id = u.user_id AND
			cd.lead_source_type_id = lst.lead_source_type_id AND
			cd.rating_type_id = rt.rating_type_id AND
			cd.stage_type_id = stage.stage_type_id AND
			cd.status_type_id = stat.status_type_id AND
			cd.user_id = userId AND
			( ( cd.estimated_close_date BETWEEN lBoundDate AND uBoundDate ) OR 
			  	( lBoundDate IS NULL OR uBoundDate is NULL )
			)
		GROUP BY
			cd.client_deal_id
		ORDER BY
			cd.estimated_revenue DESC
		LIMIT 10;
	END$$

DELIMITER;